==> odoo_19.0.20251110.zip: odoo-19.0.post20251110/odoo/addons/website/static/src/js/tours/configurator_tour.js <==
import {
    changeBackground,
    changeBackgroundColor,
    changeImage,
    changeOption,
    changePaddingSize,
    clickOnSnippet,
    clickOnText,
    selectNested,
    registerThemeHomepageTour,
} from "@website/js/tours/tour_utils";
import { _t } from "@web/core/l10n/translation";

registerThemeHomepageTour("configurator_tour", () => {
    let titleSelector = "#wrap > section:first-child";
    let title = $(titleSelector).find("h1, h2").first();
    if (!title.length) {
        titleSelector = titleSelector.replace("section:first-child", "section:nth-child(2)");
        title = $(titleSelector).find("h1, h2").first();
    }

    const isTitleTextImage = $(titleSelector).hasClass("s_text_image");
    titleSelector = titleSelector.concat(` ${title.is("h1") ? "h1" : "h2"}`);

    const shapeSelector = "#wrap > section[data-oe-shape-data]";
    const backgroundSelector = "#wrap > section:nth-child(2)";

    const imageStep = isTitleTextImage
        ? changeImage(titleSelector.replace("h2", "img"))
        : changeBackground();

    const backgroundColorStep = [changeBackgroundColor()];
    if (!isTitleTextImage) {
        backgroundColorStep.unshift(...clickOnSnippet(backgroundSelector));
    }

    const shapeStep = [];
    if ($(shapeSelector).first().length) {
        if (!$(backgroundSelector).is($(shapeSelector))) {
            shapeStep.push(...clickOnSnippet(shapeSelector));
        }
        shapeStep.push(changeOption("BackgroundShape", "we-toggler", _t("Background Shape")));
        shapeStep.push(
            selectNested(
                "we-select-page",
                "BackgroundShape",
                ":not(.o_we_pager_controls)",
                _t("Background Shape")
            )
        );
    }

    return [
        ...clickOnText(titleSelector),
        ...imageStep,
        ...backgroundColorStep,
        ...shapeStep,
        changePaddingSize("top"),
    ];
});

==> odoo_19.1a1.20251211.zip: odoo-19.1a1.post20251211/odoo/addons/website/static/src/js/tours/configurator_tour.js <==
import {
    changeBackground,
    changeBackgroundColor,
    changeImage,
    changeBackgroundShape,
    changePaddingSize,
    clickOnSnippet,
    clickOnText,
    selectNested,
    registerThemeHomepageTour,
} from "@website/js/tours/tour_utils";
import { _t } from "@web/core/l10n/translation";

registerThemeHomepageTour("configurator_tour", () => {
    let titleSelector = "#wrap > section:first-child";
    let title = $(titleSelector).find("h1, h2").first();
    if (!title.length) {
        titleSelector = titleSelector.replace("section:first-child", "section:nth-child(2)");
        title = $(titleSelector).find("h1, h2").first();
    }

    const isTitleTextImage = $(titleSelector).hasClass("s_text_image");
    titleSelector = titleSelector.concat(` ${title.is("h1") ? "h1" : "h2"}`);

    const shapeSelector = "#wrap > section[data-oe-shape-data]";
    const backgroundSelector = "#wrap > section:nth-child(2)";

    const imageStep = isTitleTextImage
        ? changeImage(titleSelector.replace("h2", "img"))
        : changeBackground();

    const backgroundColorStep = [changeBackgroundColor()];
    if (!isTitleTextImage) {
        backgroundColorStep.unshift(...clickOnSnippet(backgroundSelector));
    }

    const shapeStep = [];
    if ($(shapeSelector).first().length) {
        if (!$(backgroundSelector).is($(shapeSelector))) {
            shapeStep.push(...clickOnSnippet(shapeSelector));
        }
        shapeStep.push(...changeBackgroundShape());
        shapeStep.push(
            selectNested(
                "we-select-page",
                "BackgroundShape",
                ":not(.o_we_pager_controls)",
                _t("Background Shape")
            )
        );
    }

    return [
        ...clickOnText(titleSelector),
        ...imageStep,
        ...backgroundColorStep,
        ...shapeStep,
        changePaddingSize("top"),
    ];
});
